@@ -19,7 +19,7 @@ def delete_topics() -> None:
 
     a = AdminClient({'bootstrap.servers': bootstrap_servers})
 
-    conf = pkgutil.get_data("jlab_jaws", "avro/topics.json")
+    conf = pkgutil.get_data("jaws_libp", "avro/topics.json")
 
     topics = json.loads(conf)
 
