@@ -18,7 +18,7 @@ def describe_schemas() -> None:
     sr_conf = {'url':  os.environ.get('SCHEMA_REGISTRY', 'http://localhost:8081')}
     client = SchemaRegistryClient(sr_conf)
 
-    conf = pkgutil.get_data("jlab_jaws", "avro/schema-registry.json")
+    conf = pkgutil.get_data("jaws_libp", "avro/schema-registry.json")
 
     records = json.loads(conf)
 
